# OSDNClient::ProjectFrsApi

All URIs are relative to *https://osdn.net/api/v0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_package**](ProjectFrsApi.md#create_package) | **POST** /project/{id_or_name}/frs | 
[**create_release**](ProjectFrsApi.md#create_release) | **POST** /project/{id_or_name}/frs/{package_id} | 
[**create_release_file**](ProjectFrsApi.md#create_release_file) | **POST** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**delete_package**](ProjectFrsApi.md#delete_package) | **DELETE** /project/{id_or_name}/frs/{package_id} | 
[**delete_release**](ProjectFrsApi.md#delete_release) | **DELETE** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**delete_release_file**](ProjectFrsApi.md#delete_release_file) | **DELETE** /project/{id_or_name}/frs/{package_id}/{release_id}/{file_id} | 
[**draft_release**](ProjectFrsApi.md#draft_release) | **GET** /project/{id_or_name}/frs/{package_id}/draft | 
[**get_frs_adminprefs**](ProjectFrsApi.md#get_frs_adminprefs) | **GET** /project/{id_or_name}/frs/admin | 
[**get_package**](ProjectFrsApi.md#get_package) | **GET** /project/{id_or_name}/frs/{package_id} | 
[**get_release**](ProjectFrsApi.md#get_release) | **GET** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**get_release_file**](ProjectFrsApi.md#get_release_file) | **GET** /project/{id_or_name}/frs/{package_id}/{release_id}/{file_id} | 
[**list_packages**](ProjectFrsApi.md#list_packages) | **GET** /project/{id_or_name}/frs | 
[**update_frs_adminprefs**](ProjectFrsApi.md#update_frs_adminprefs) | **PATCH** /project/{id_or_name}/frs/admin | 
[**update_package**](ProjectFrsApi.md#update_package) | **PATCH** /project/{id_or_name}/frs/{package_id} | 
[**update_release**](ProjectFrsApi.md#update_release) | **PATCH** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**update_release_file**](ProjectFrsApi.md#update_release_file) | **PATCH** /project/{id_or_name}/frs/{package_id}/{release_id}/{file_id} | 


# **create_package**
> Package create_package(id_or_name, name, opts)



Create a package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

name = "name_example" # String | package name

opts = { 
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.create_package(id_or_name, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->create_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **name** | **String**| package name | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**Package**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_release**
> Release create_release(id_or_name, package_id, name, opts)



Create new release in specified package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

name = "name_example" # String | Release name

opts = { 
  visibility: "visibility_example", # String | visibility status (public, hidden or private)
  time: DateTime.parse("2013-10-20T19:20:30+01:00"), # DateTime | Release datetime. If you set future time, the release hide until specified time.
  release_note: "release_note_example", # String | Release note body text.
  change_log: "change_log_example" # String | Changelog body text.
}

begin
  result = api_instance.create_release(id_or_name, package_id, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->create_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **name** | **String**| Release name | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 
 **time** | **DateTime**| Release datetime. If you set future time, the release hide until specified time. | [optional] 
 **release_note** | **String**| Release note body text. | [optional] 
 **change_log** | **String**| Changelog body text. | [optional] 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_release_file**
> RelFile create_release_file(id_or_name, package_id, release_id, file, opts)



Create new file in target release.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file = File.new("/path/to/file.txt") # File | Upload file in \"multipart/form-data\".

opts = { 
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.create_release_file(id_or_name, package_id, release_id, file, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->create_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file** | **File**| Upload file in \&quot;multipart/form-data\&quot;. | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**RelFile**](RelFile.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: Not defined



# **delete_package**
> delete_package(id_or_name, package_id)



Delete taret package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 


begin
  api_instance.delete_package(id_or_name, package_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->delete_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_release**
> delete_release(id_or_name, package_id, release_id)



Delete target release.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 


begin
  api_instance.delete_release(id_or_name, package_id, release_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->delete_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_release_file**
> delete_release_file(id_or_name, package_id, release_id, file_id)



Delete target file.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file_id = 56 # Integer | 


begin
  api_instance.delete_release_file(id_or_name, package_id, release_id, file_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->delete_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **draft_release**
> Release draft_release(id_or_name, package_id)



Get release draft in specified package. If draft is not exist, it will be created automatically.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 


begin
  result = api_instance.draft_release(id_or_name, package_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->draft_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_frs_adminprefs**
> FrsAdminPrefs get_frs_adminprefs(id_or_name)



Get project frs admin preferences.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.get_frs_adminprefs(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->get_frs_adminprefs: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**FrsAdminPrefs**](FrsAdminPrefs.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_package**
> Package get_package(id_or_name, package_id)



Get specified package info and release list of the package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 


begin
  result = api_instance.get_package(id_or_name, package_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->get_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 

### Return type

[**Package**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_release**
> Release get_release(id_or_name, package_id, release_id)



Get specified release info and file list of the release.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 


begin
  result = api_instance.get_release(id_or_name, package_id, release_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->get_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_release_file**
> RelFile get_release_file(id_or_name, package_id, release_id, file_id)



Get single file object.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file_id = 56 # Integer | 


begin
  result = api_instance.get_release_file(id_or_name, package_id, release_id, file_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->get_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file_id** | **Integer**|  | 

### Return type

[**RelFile**](RelFile.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_packages**
> Array&lt;Package&gt; list_packages(id_or_name)



Get package list of specified project.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.list_packages(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->list_packages: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Array&lt;Package&gt;**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_frs_adminprefs**
> FrsAdminPrefs update_frs_adminprefs(id_or_name, opts)



Update project frs admin preferences.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

opts = { 
  allow_overwrite: true # BOOLEAN | Allow overwrite files when filenames are conflict
}

begin
  result = api_instance.update_frs_adminprefs(id_or_name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->update_frs_adminprefs: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **allow_overwrite** | **BOOLEAN**| Allow overwrite files when filenames are conflict | [optional] 

### Return type

[**FrsAdminPrefs**](FrsAdminPrefs.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_package**
> Package update_package(id_or_name, package_id, opts)



Update tagret package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

opts = { 
  name: "name_example", # String | package name
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.update_package(id_or_name, package_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->update_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **name** | **String**| package name | [optional] 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**Package**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_release**
> Release update_release(id_or_name, package_id, release_id, opts)



Update target release. (Note: If you update draft release, the release will be public automatically.) 

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

opts = { 
  visibility: "visibility_example", # String | visibility status (public, hidden or private)
  name: "name_example", # String | Release name
  time: DateTime.parse("2013-10-20T19:20:30+01:00"), # DateTime | Release datetime. If you set future time, the release hide until specified time.
  move_to_package_id: 56 # Integer | If this parameter is specified, the release move to another package.
}

begin
  result = api_instance.update_release(id_or_name, package_id, release_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->update_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 
 **name** | **String**| Release name | [optional] 
 **time** | **DateTime**| Release datetime. If you set future time, the release hide until specified time. | [optional] 
 **move_to_package_id** | **Integer**| If this parameter is specified, the release move to another package. | [optional] 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_release_file**
> RelFile update_release_file(id_or_name, package_id, release_id, file_id, opts)



Change visibility of target file.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectFrsApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file_id = 56 # Integer | 

opts = { 
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.update_release_file(id_or_name, package_id, release_id, file_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectFrsApi->update_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file_id** | **Integer**|  | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**RelFile**](RelFile.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



