# OSDNClient::ProjectSCMApi

All URIs are relative to *https://osdn.net/api/v0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_project_bzr**](ProjectSCMApi.md#create_project_bzr) | **POST** /project/{id_or_name}/bzr | 
[**create_project_git**](ProjectSCMApi.md#create_project_git) | **POST** /project/{id_or_name}/git | 
[**create_project_git_hook**](ProjectSCMApi.md#create_project_git_hook) | **POST** /project/{id_or_name}/git/{repo_id}/hooks | 
[**create_project_hg**](ProjectSCMApi.md#create_project_hg) | **POST** /project/{id_or_name}/hg | 
[**delete_project_git_hook**](ProjectSCMApi.md#delete_project_git_hook) | **DELETE** /project/{id_or_name}/git/{repo_id}/hooks/{hook_id} | 
[**disable_project_bzr**](ProjectSCMApi.md#disable_project_bzr) | **DELETE** /project/{id_or_name}/bzr/{repo_id} | 
[**disable_project_git**](ProjectSCMApi.md#disable_project_git) | **DELETE** /project/{id_or_name}/git/{repo_id} | 
[**disable_project_hg**](ProjectSCMApi.md#disable_project_hg) | **DELETE** /project/{id_or_name}/hg/{repo_id} | 
[**get_project_bzr**](ProjectSCMApi.md#get_project_bzr) | **GET** /project/{id_or_name}/bzr/{repo_id} | 
[**get_project_git**](ProjectSCMApi.md#get_project_git) | **GET** /project/{id_or_name}/git/{repo_id} | 
[**get_project_git_hook**](ProjectSCMApi.md#get_project_git_hook) | **GET** /project/{id_or_name}/git/{repo_id}/hooks/{hook_id} | 
[**get_project_hg**](ProjectSCMApi.md#get_project_hg) | **GET** /project/{id_or_name}/hg/{repo_id} | 
[**get_project_svn**](ProjectSCMApi.md#get_project_svn) | **GET** /project/{id_or_name}/svn | 
[**list_project_bzr**](ProjectSCMApi.md#list_project_bzr) | **GET** /project/{id_or_name}/bzr | 
[**list_project_git**](ProjectSCMApi.md#list_project_git) | **GET** /project/{id_or_name}/git | 
[**list_project_git_hook**](ProjectSCMApi.md#list_project_git_hook) | **GET** /project/{id_or_name}/git/{repo_id}/hooks | 
[**list_project_hg**](ProjectSCMApi.md#list_project_hg) | **GET** /project/{id_or_name}/hg | 
[**update_project_bzr**](ProjectSCMApi.md#update_project_bzr) | **PATCH** /project/{id_or_name}/bzr/{repo_id} | 
[**update_project_git**](ProjectSCMApi.md#update_project_git) | **PATCH** /project/{id_or_name}/git/{repo_id} | 
[**update_project_hg**](ProjectSCMApi.md#update_project_hg) | **PATCH** /project/{id_or_name}/hg/{repo_id} | 


# **create_project_bzr**
> ProjectBzr create_project_bzr(id_or_name, name, opts)



Create a new bzr repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

name = "name_example" # String | 

opts = { 
  description: "description_example" # String | 
}

begin
  result = api_instance.create_project_bzr(id_or_name, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->create_project_bzr: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **name** | **String**|  | 
 **description** | **String**|  | [optional] 

### Return type

[**ProjectBzr**](ProjectBzr.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_project_git**
> ProjectGit create_project_git(id_or_name, name, opts)



Create a new git repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

name = "name_example" # String | 

opts = { 
  description: "description_example", # String | 
  mail_enabled: true, # BOOLEAN | 
  mail_recipients: "mail_recipients_example", # String | 
  allow_non_fast_forward: true, # BOOLEAN | 
  default_branch: "default_branch_example" # String | 
}

begin
  result = api_instance.create_project_git(id_or_name, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->create_project_git: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **name** | **String**|  | 
 **description** | **String**|  | [optional] 
 **mail_enabled** | **BOOLEAN**|  | [optional] 
 **mail_recipients** | **String**|  | [optional] 
 **allow_non_fast_forward** | **BOOLEAN**|  | [optional] 
 **default_branch** | **String**|  | [optional] 

### Return type

[**ProjectGit**](ProjectGit.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_project_git_hook**
> ScmHook create_project_git_hook(id_or_name, repo_id, target_url)



Create a new hook for project git repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 

target_url = "target_url_example" # String | 


begin
  result = api_instance.create_project_git_hook(id_or_name, repo_id, target_url)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->create_project_git_hook: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 
 **target_url** | **String**|  | 

### Return type

[**ScmHook**](ScmHook.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_project_hg**
> ProjectHg create_project_hg(id_or_name, name, opts)



Create a new hg repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

name = "name_example" # String | 

opts = { 
  description: "description_example", # String | 
  mail_recipients: "mail_recipients_example" # String | 
}

begin
  result = api_instance.create_project_hg(id_or_name, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->create_project_hg: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **name** | **String**|  | 
 **description** | **String**|  | [optional] 
 **mail_recipients** | **String**|  | [optional] 

### Return type

[**ProjectHg**](ProjectHg.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_project_git_hook**
> delete_project_git_hook(id_or_name, repo_id, hook_id)



Delete a Git repository hook

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 

hook_id = 56 # Integer | 


begin
  api_instance.delete_project_git_hook(id_or_name, repo_id, hook_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->delete_project_git_hook: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 
 **hook_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **disable_project_bzr**
> ProjectBzr disable_project_bzr(id_or_name, repo_id)



Disable a bzr repository (not an actual delete, just a shorthand for updating with active=false)

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.disable_project_bzr(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->disable_project_bzr: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**ProjectBzr**](ProjectBzr.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **disable_project_git**
> ProjectGit disable_project_git(id_or_name, repo_id)



Disable a git repository (not an actual delete, just a shorthand for updating with active=false)

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.disable_project_git(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->disable_project_git: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**ProjectGit**](ProjectGit.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **disable_project_hg**
> ProjectHg disable_project_hg(id_or_name, repo_id)



Disable a hg repository (not an actual delete, just a shorthand for updating with active=false)

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.disable_project_hg(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->disable_project_hg: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**ProjectHg**](ProjectHg.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_project_bzr**
> ProjectBzr get_project_bzr(id_or_name, repo_id)



Get a bzr repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.get_project_bzr(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->get_project_bzr: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**ProjectBzr**](ProjectBzr.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_project_git**
> ProjectGit get_project_git(id_or_name, repo_id)



Get a git repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.get_project_git(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->get_project_git: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**ProjectGit**](ProjectGit.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_project_git_hook**
> ScmHook get_project_git_hook(id_or_name, repo_id, hook_id)



Get a repository hook

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 

hook_id = 56 # Integer | 


begin
  result = api_instance.get_project_git_hook(id_or_name, repo_id, hook_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->get_project_git_hook: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 
 **hook_id** | **Integer**|  | 

### Return type

[**ScmHook**](ScmHook.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_project_hg**
> ProjectHg get_project_hg(id_or_name, repo_id)



Get a hg repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.get_project_hg(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->get_project_hg: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**ProjectHg**](ProjectHg.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_project_svn**
> ProjectSvn get_project_svn(id_or_name)



Get Subversion repository of the project

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.get_project_svn(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->get_project_svn: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**ProjectSvn**](ProjectSvn.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_project_bzr**
> Array&lt;ProjectBzr&gt; list_project_bzr(id_or_name)



Get Bazzar repository list

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.list_project_bzr(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->list_project_bzr: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Array&lt;ProjectBzr&gt;**](ProjectBzr.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_project_git**
> Array&lt;ProjectGit&gt; list_project_git(id_or_name)



Get git repository list

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.list_project_git(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->list_project_git: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Array&lt;ProjectGit&gt;**](ProjectGit.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_project_git_hook**
> Array&lt;ScmHook&gt; list_project_git_hook(id_or_name, repo_id)



Get Git repository hook list

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 


begin
  result = api_instance.list_project_git_hook(id_or_name, repo_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->list_project_git_hook: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 

### Return type

[**Array&lt;ScmHook&gt;**](ScmHook.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_project_hg**
> Array&lt;ProjectHg&gt; list_project_hg(id_or_name)



Get Mercurial repository list

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.list_project_hg(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->list_project_hg: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Array&lt;ProjectHg&gt;**](ProjectHg.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_project_bzr**
> ProjectBzr update_project_bzr(id_or_name, repo_id, opts)



Update a bzr repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 

opts = { 
  description: "description_example", # String | 
  active: true # BOOLEAN | 
}

begin
  result = api_instance.update_project_bzr(id_or_name, repo_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->update_project_bzr: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 
 **description** | **String**|  | [optional] 
 **active** | **BOOLEAN**|  | [optional] 

### Return type

[**ProjectBzr**](ProjectBzr.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_project_git**
> ProjectGit update_project_git(id_or_name, repo_id, opts)



Update a git repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 

opts = { 
  description: "description_example", # String | 
  mail_enabled: true, # BOOLEAN | 
  mail_recipients: "mail_recipients_example", # String | 
  allow_non_fast_forward: true, # BOOLEAN | 
  default_branch: "default_branch_example", # String | 
  active: true # BOOLEAN | 
}

begin
  result = api_instance.update_project_git(id_or_name, repo_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->update_project_git: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 
 **description** | **String**|  | [optional] 
 **mail_enabled** | **BOOLEAN**|  | [optional] 
 **mail_recipients** | **String**|  | [optional] 
 **allow_non_fast_forward** | **BOOLEAN**|  | [optional] 
 **default_branch** | **String**|  | [optional] 
 **active** | **BOOLEAN**|  | [optional] 

### Return type

[**ProjectGit**](ProjectGit.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_project_hg**
> ProjectHg update_project_hg(id_or_name, repo_id, opts)



Update a hg repository

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectSCMApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

repo_id = 56 # Integer | 

opts = { 
  description: "description_example", # String | 
  mail_recipients: "mail_recipients_example", # String | 
  active: true # BOOLEAN | 
}

begin
  result = api_instance.update_project_hg(id_or_name, repo_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectSCMApi->update_project_hg: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **repo_id** | **Integer**|  | 
 **description** | **String**|  | [optional] 
 **mail_recipients** | **String**|  | [optional] 
 **active** | **BOOLEAN**|  | [optional] 

### Return type

[**ProjectHg**](ProjectHg.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



