# OSDNClient::UserApi

All URIs are relative to *https://osdn.net/api/v0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_user**](UserApi.md#get_user) | **GET** /user/{id_or_name} | 
[**get_user_history**](UserApi.md#get_user_history) | **GET** /user/{id_or_name}/history | 
[**get_user_stats_daily**](UserApi.md#get_user_stats_daily) | **GET** /user/{id_or_name}/stats/daily | 
[**get_user_stats_monthly**](UserApi.md#get_user_stats_monthly) | **GET** /user/{id_or_name}/stats/monthly | 
[**update_user_icon**](UserApi.md#update_user_icon) | **POST** /user/{id_or_name}/icon | 
[**update_user_photo**](UserApi.md#update_user_photo) | **POST** /user/{id_or_name}/photo | 


# **get_user**
> User get_user(id_or_name)



Get user profile. 

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::UserApi.new

id_or_name = "id_or_name_example" # String | numeric user id or user name


begin
  result = api_instance.get_user(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling UserApi->get_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric user id or user name | 

### Return type

[**User**](User.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_user_history**
> Array&lt;History&gt; get_user_history(id_or_name)



get user monthly stats.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::UserApi.new

id_or_name = "id_or_name_example" # String | numeric user id or user name


begin
  result = api_instance.get_user_history(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling UserApi->get_user_history: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric user id or user name | 

### Return type

[**Array&lt;History&gt;**](History.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_user_stats_daily**
> Array&lt;UserStats&gt; get_user_stats_daily(id_or_name)



get user daily stats.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::UserApi.new

id_or_name = "id_or_name_example" # String | numeric user id or user name


begin
  result = api_instance.get_user_stats_daily(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling UserApi->get_user_stats_daily: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric user id or user name | 

### Return type

[**Array&lt;UserStats&gt;**](UserStats.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_user_stats_monthly**
> Array&lt;UserStats&gt; get_user_stats_monthly(id_or_name)



get user monthly stats.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::UserApi.new

id_or_name = "id_or_name_example" # String | numeric user id or user name


begin
  result = api_instance.get_user_stats_monthly(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling UserApi->get_user_stats_monthly: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric user id or user name | 

### Return type

[**Array&lt;UserStats&gt;**](UserStats.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_user_icon**
> update_user_icon(id_or_name, image)



Update user icon, the image will be resized to 12x12 automatically. 

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::UserApi.new

id_or_name = "id_or_name_example" # String | numeric user id or user name

image = File.new("/path/to/file.txt") # File | The image data to update, you need to send with multipart/form-data.


begin
  api_instance.update_user_icon(id_or_name, image)
rescue OSDNClient::ApiError => e
  puts "Exception when calling UserApi->update_user_icon: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric user id or user name | 
 **image** | **File**| The image data to update, you need to send with multipart/form-data. | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: Not defined



# **update_user_photo**
> update_user_photo(id_or_name, image)



Update user profile photo. 

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::UserApi.new

id_or_name = "id_or_name_example" # String | numeric user id or user name

image = File.new("/path/to/file.txt") # File | The image data to update, you need to send with multipart/form-data.


begin
  api_instance.update_user_photo(id_or_name, image)
rescue OSDNClient::ApiError => e
  puts "Exception when calling UserApi->update_user_photo: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric user id or user name | 
 **image** | **File**| The image data to update, you need to send with multipart/form-data. | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: Not defined



